## RouterAdmin

- 路由注册管理基类

### 继承基类

- #### [BaseAdmin](../BaseAdmin)

- #### [RouterMixin](../../crud/RouterMixin)

### 派生子类

- [PageAdmin](../PageAdmin)

### 字段

#### router_path

- 当前路由注册器,基础路径

### 方法

#### register_router

注册页面路由.





